@@ -1,9 +1,7 @@
 class Error(Exception):
     """Base class for exceptions in this module."""
-    message: str
 
-    def __str__(self):
-        return self.message
+    pass
 
 
 class EmptyUrlFieldError(Error):
@@ -51,36 +49,8 @@ class InvalidPathError(Error):
         self.message = f"DIR {path} is not a valid directory."
 
 
-class ImageDownloadError(Error):
-    def __init__(self, url):
-        self.message = f"Could not download image at {url}."
-
-
-class WrongMetadataLinkError(Error):
-    def __init__(self, url):
-        self.message = (
-            f"The url at {url} does not point to a valid Discogs.com release page."
-        )
-
-
-class BrokenDiscogsLinkError(Error):
-    def __init__(self, url):
-        self.message = f"The url at {url} is unavailable."
-
-
-class TracknumberMismatchError(Error):
-    def __init__(self, playlist, album):
-        self.message = f"Mismatch between the number of selected tracks in YouTube playlist {playlist} " \
-                       f"and Discogs release for {album}."
-
-
 # bad url
 # url not for playlist
 # title file not found
 # invalid line in title file
 # directory not found
-
-
-if __name__ == "__main__":
-    e = ImageDownloadError("jxnjsxsjx")
-    print(str(e))
